camelot.camelot.view.helpers

Package camelot :: Package camelot :: Package view :: Module helpers |
[hide private]
[frames] | no frames]

# Module helpers

source code

collection of helper functions

Functions | [hide private]
createAction(parent, text, slot=None, shortcut=`'````'`, actionicon=`'````'`, tip=`'````'`, checkable=False, signal=`'``triggered()``'`, widgetaction=False) creates and returns a QAction object | source code
addActions(target, actions) add action objects to menus, menubars, and toolbars if action is None, add a toolbar, however we must explicitly add separator actions in the case of context menus. | source code